==> egov-common-1.0.10-sources.jar: com/gtis/plat/vo/SjdVo.java <==
package com.gtis.plat.vo;

import java.util.Date;

/**
 * @文件名 SjdVo.java
 * @作者 卢向伟
 * @创建日期 2013-1-10
 * @创建时间 上午11:18:20 
 * @版本号 V 1.0
 */
public class SjdVo implements java.io.Serializable {
	private String sjdid;
	private String proid;             
	private String sjd_bh;               //收件单—编号          
	private String sjd_sqlx;             //收件单—申请类型      
	private String sjd_jjr;              //收件单—交件人        
	private String sjd_lxdh;             //收件单—交件人联系电话
	private Integer sjd_cnqx;             //收件单—交件人承诺期限
	private String sjd_sjr;              //收件单—收件人        
	private Date sjd_sj_date;          //收件单—收件日期      
	private String sjd_bz;               //收件单—备注  
	private Integer sjd_bh_year;               //收件单—编号—年份          
	private Integer sjd_bh_xh;               //收件单—编号—序号    
	private byte[] sjd_cl;//收件单材料
	//其他数据
	private String address;//土地坐落
	private String sqr;//申请人
	private String busiType;//业务类型
	public String getSjd_bh() {
		return sjd_bh;
	}
	public void setSjd_bh(String sjd_bh) {
		this.sjd_bh = sjd_bh;
	}
	public String getSjd_sqlx() {
		return sjd_sqlx;
	}
	public void setSjd_sqlx(String sjd_sqlx) {
		this.sjd_sqlx = sjd_sqlx;
	}
	public String getSjd_jjr() {
		return sjd_jjr;
	}
	public void setSjd_jjr(String sjd_jjr) {
		this.sjd_jjr = sjd_jjr;
	}
	public String getSjd_lxdh() {
		return sjd_lxdh;
	}
	public void setSjd_lxdh(String sjd_lxdh) {
		this.sjd_lxdh = sjd_lxdh;
	}
	public Integer getSjd_cnqx() {
		return sjd_cnqx;
	}
	public void setSjd_cnqx(Integer sjd_cnqx) {
		this.sjd_cnqx = sjd_cnqx;
	}
	public String getSjd_sjr() {
		return sjd_sjr;
	}
	public void setSjd_sjr(String sjd_sjr) {
		this.sjd_sjr = sjd_sjr;
	}
	public Date getSjd_sj_date() {
		return sjd_sj_date;
	}
	public void setSjd_sj_date(Date sjd_sj_date) {
		this.sjd_sj_date = sjd_sj_date;
	}
	public String getSjd_bz() {
		return sjd_bz;
	}
	public void setSjd_bz(String sjd_bz) {
		this.sjd_bz = sjd_bz;
	}
	public String getSjdid() {
		return sjdid;
	}
	public void setSjdid(String sjdid) {
		this.sjdid = sjdid;
	}
	public String getProid() {
		return proid;
	}
	public void setProid(String proid) {
		this.proid = proid;
	}
	public String getAddress() {
		return address;
	}
	public void setAddress(String address) {
		this.address = address;
	}
	public String getSqr() {
		return sqr;
	}
	public void setSqr(String sqr) {
		this.sqr = sqr;
	}
	public String getBusiType() {
		return busiType;
	}
	public void setBusiType(String busiType) {
		this.busiType = busiType;
	}
	public Integer getSjd_bh_year() {
		return sjd_bh_year;
	}
	public void setSjd_bh_year(Integer sjd_bh_year) {
		this.sjd_bh_year = sjd_bh_year;
	}
	public Integer getSjd_bh_xh() {
		return sjd_bh_xh;
	}
	public void setSjd_bh_xh(Integer sjd_bh_xh) {
		this.sjd_bh_xh = sjd_bh_xh;
	}
	public byte[] getSjd_cl() {
		return sjd_cl;
	}
	public void setSjd_cl(byte[] sjd_cl) {
		this.sjd_cl = sjd_cl;
	}
}

==> egov-common-1.1.12.1-sources.jar: com/gtis/plat/vo/SjdVo.java <==
package com.gtis.plat.vo;

import java.util.Date;

/**
 * @文件名 SjdVo.java
 * @作者 卢向伟
 * @创建日期 2013-1-10
 * @创建时间 上午11:18:20 
 * @版本号 V 1.0
 */
public class SjdVo implements java.io.Serializable {
	private String sjdid;
	private String proid;             
	private String sjd_bh;               //收件单—编号          
	private String sjd_sqlx;             //收件单—申请类型      
	private String sjd_jjr;              //收件单—交件人        
	private String sjd_lxdh;             //收件单—交件人联系电话
	private String sjd_cnqx;             //收件单—交件人承诺期限
	private String sjd_sjr;              //收件单—收件人        
	private Date sjd_sj_date;          //收件单—收件日期      
	private String sjd_bz;               //收件单—备注  
	private Integer sjd_bh_year;               //收件单—编号—年份          
	private Integer sjd_bh_xh;               //收件单—编号—序号    
	private byte[] sjd_cl;//收件单材料
	//其他数据
	private String address;//土地坐落
	private String sqr;//申请人
	private String busiType;//业务类型
	public String getSjd_bh() {
		return sjd_bh;
	}
	public void setSjd_bh(String sjd_bh) {
		this.sjd_bh = sjd_bh;
	}
	public String getSjd_sqlx() {
		return sjd_sqlx;
	}
	public void setSjd_sqlx(String sjd_sqlx) {
		this.sjd_sqlx = sjd_sqlx;
	}
	public String getSjd_jjr() {
		return sjd_jjr;
	}
	public void setSjd_jjr(String sjd_jjr) {
		this.sjd_jjr = sjd_jjr;
	}
	public String getSjd_lxdh() {
		return sjd_lxdh;
	}
	public void setSjd_lxdh(String sjd_lxdh) {
		this.sjd_lxdh = sjd_lxdh;
	}
	public String getSjd_cnqx() {
		return sjd_cnqx;
	}
	public void setSjd_cnqx(String sjd_cnqx) {
		this.sjd_cnqx = sjd_cnqx;
	}
	public String getSjd_sjr() {
		return sjd_sjr;
	}
	public void setSjd_sjr(String sjd_sjr) {
		this.sjd_sjr = sjd_sjr;
	}
	public Date getSjd_sj_date() {
		return sjd_sj_date;
	}
	public void setSjd_sj_date(Date sjd_sj_date) {
		this.sjd_sj_date = sjd_sj_date;
	}
	public String getSjd_bz() {
		return sjd_bz;
	}
	public void setSjd_bz(String sjd_bz) {
		this.sjd_bz = sjd_bz;
	}
	public String getSjdid() {
		return sjdid;
	}
	public void setSjdid(String sjdid) {
		this.sjdid = sjdid;
	}
	public String getProid() {
		return proid;
	}
	public void setProid(String proid) {
		this.proid = proid;
	}
	public String getAddress() {
		return address;
	}
	public void setAddress(String address) {
		this.address = address;
	}
	public String getSqr() {
		return sqr;
	}
	public void setSqr(String sqr) {
		this.sqr = sqr;
	}
	public String getBusiType() {
		return busiType;
	}
	public void setBusiType(String busiType) {
		this.busiType = busiType;
	}
	public Integer getSjd_bh_year() {
		return sjd_bh_year;
	}
	public void setSjd_bh_year(Integer sjd_bh_year) {
		this.sjd_bh_year = sjd_bh_year;
	}
	public Integer getSjd_bh_xh() {
		return sjd_bh_xh;
	}
	public void setSjd_bh_xh(Integer sjd_bh_xh) {
		this.sjd_bh_xh = sjd_bh_xh;
	}
	public byte[] getSjd_cl() {
		return sjd_cl;
	}
	public void setSjd_cl(byte[] sjd_cl) {
		this.sjd_cl = sjd_cl;
	}
}
